Module slashing

Module slashing 

Modules

core
This module contains the sol! generated bindings for solidity contracts. This is autogenerated code. Do not manually edit these files. These files may be overwritten by the codegen system at any time.
middleware
This module contains the sol! generated bindings for solidity contracts. This is autogenerated code. Do not manually edit these files. These files may be overwritten by the codegen system at any time.
sdk
This module contains the sol! generated bindings for solidity contracts. This is autogenerated code. Do not manually edit these files. These files may be overwritten by the codegen system at any time.