pub struct createOperatorSetsCall {
pub avs: Address,
pub params: Vec<<CreateSetParams as SolType>::RustType>,
}Expand description
Function with signature createOperatorSets(address,(uint32,address[])[]) and selector 0x261f84e0.
solidity function createOperatorSets(address avs, IAllocationManagerTypes.CreateSetParams[] memory params) external;
Fields
avs: Addressparams: Vec<<CreateSetParams as SolType>::RustType>Trait Implementations
Sourceimpl Clone for createOperatorSetsCall
impl Clone for createOperatorSetsCall
Sourcefn clone(&self) -> createOperatorSetsCall
fn clone(&self) -> createOperatorSetsCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for createOperatorSetsCall
impl Debug for createOperatorSetsCall
Sourceimpl Default for createOperatorSetsCall
impl Default for createOperatorSetsCall
Sourcefn default() -> createOperatorSetsCall
fn default() -> createOperatorSetsCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for createOperatorSetsCall
impl<'de> Deserialize<'de> for createOperatorSetsCall
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for createOperatorSetsCall
impl Hash for createOperatorSetsCall
Sourceimpl PartialEq for createOperatorSetsCall
impl PartialEq for createOperatorSetsCall
Sourcefn eq(&self, other: &createOperatorSetsCall) -> bool
fn eq(&self, other: &createOperatorSetsCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for createOperatorSetsCall
impl Serialize for createOperatorSetsCall
Sourceimpl SolCall for createOperatorSetsCall
impl SolCall for createOperatorSetsCall
Sourceconst SIGNATURE: &'static str = "createOperatorSets(address,(uint32,address[])[])"
const SIGNATURE: &'static str = "createOperatorSets(address,(uint32,address[])[])"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Address, Array<CreateSetParams>)
type Parameters<'a> = (Address, Array<CreateSetParams>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<createOperatorSetsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<createOperatorSetsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = createOperatorSetsReturn
type Return = createOperatorSetsReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<createOperatorSetsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<createOperatorSetsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for createOperatorSetsCall
impl StructuralPartialEq for createOperatorSetsCall