pub struct getAllocatedStakeCall {
pub operatorSet: <OperatorSet as SolType>::RustType,
pub operators: Vec<Address>,
pub strategies: Vec<Address>,
}Expand description
Function with signature getAllocatedStake((address,uint32),address[],address[]) and selector 0x2b453a9a.
solidity function getAllocatedStake(OperatorSet memory operatorSet, address[] memory operators, address[] memory strategies) external view returns (uint256[][] memory);
Fields
operatorSet: <OperatorSet as SolType>::RustTypeoperators: Vec<Address>strategies: Vec<Address>Trait Implementations
Sourceimpl Clone for getAllocatedStakeCall
impl Clone for getAllocatedStakeCall
Sourcefn clone(&self) -> getAllocatedStakeCall
fn clone(&self) -> getAllocatedStakeCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getAllocatedStakeCall
impl Debug for getAllocatedStakeCall
Sourceimpl Default for getAllocatedStakeCall
impl Default for getAllocatedStakeCall
Sourcefn default() -> getAllocatedStakeCall
fn default() -> getAllocatedStakeCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getAllocatedStakeCall
impl<'de> Deserialize<'de> for getAllocatedStakeCall
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for getAllocatedStakeCall
impl Hash for getAllocatedStakeCall
Sourceimpl PartialEq for getAllocatedStakeCall
impl PartialEq for getAllocatedStakeCall
Sourcefn eq(&self, other: &getAllocatedStakeCall) -> bool
fn eq(&self, other: &getAllocatedStakeCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getAllocatedStakeCall
impl Serialize for getAllocatedStakeCall
Sourceimpl SolCall for getAllocatedStakeCall
impl SolCall for getAllocatedStakeCall
Sourceconst SIGNATURE: &'static str = "getAllocatedStake((address,uint32),address[],address[])"
const SIGNATURE: &'static str = "getAllocatedStake((address,uint32),address[],address[])"
The function’s ABI signature.
Sourcetype Parameters<'a> = (OperatorSet, Array<Address>, Array<Address>)
type Parameters<'a> = (OperatorSet, Array<Address>, Array<Address>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<getAllocatedStakeCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getAllocatedStakeCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Array<Array<Uint<256>>>,)
type ReturnTuple<'a> = (Array<Array<Uint<256>>>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<getAllocatedStakeCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getAllocatedStakeCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for getAllocatedStakeCall
impl StructuralPartialEq for getAllocatedStakeCall