pub struct getMaxMagnitudeCall {
pub operator: Address,
pub strategy: Address,
}Expand description
Function with signature getMaxMagnitude(address,address) and selector 0xa9333ec8.
solidity function getMaxMagnitude(address operator, address strategy) external view returns (uint64);
Fields
operator: Addressstrategy: AddressTrait Implementations
Sourceimpl Clone for getMaxMagnitudeCall
impl Clone for getMaxMagnitudeCall
Sourcefn clone(&self) -> getMaxMagnitudeCall
fn clone(&self) -> getMaxMagnitudeCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getMaxMagnitudeCall
impl Debug for getMaxMagnitudeCall
Sourceimpl Default for getMaxMagnitudeCall
impl Default for getMaxMagnitudeCall
Sourcefn default() -> getMaxMagnitudeCall
fn default() -> getMaxMagnitudeCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getMaxMagnitudeCall
impl<'de> Deserialize<'de> for getMaxMagnitudeCall
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for getMaxMagnitudeCall
impl Hash for getMaxMagnitudeCall
Sourceimpl PartialEq for getMaxMagnitudeCall
impl PartialEq for getMaxMagnitudeCall
Sourcefn eq(&self, other: &getMaxMagnitudeCall) -> bool
fn eq(&self, other: &getMaxMagnitudeCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getMaxMagnitudeCall
impl Serialize for getMaxMagnitudeCall
Sourceimpl SolCall for getMaxMagnitudeCall
impl SolCall for getMaxMagnitudeCall
Sourceconst SIGNATURE: &'static str = "getMaxMagnitude(address,address)"
const SIGNATURE: &'static str = "getMaxMagnitude(address,address)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Address, Address)
type Parameters<'a> = (Address, Address)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<getMaxMagnitudeCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getMaxMagnitudeCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Uint<64>,)
type ReturnTuple<'a> = (Uint<64>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<getMaxMagnitudeCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getMaxMagnitudeCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for getMaxMagnitudeCall
impl StructuralPartialEq for getMaxMagnitudeCall