pub struct getRegisteredSetsCall {
pub operator: Address,
}Expand description
Function with signature getRegisteredSets(address) and selector 0x79ae50cd.
solidity function getRegisteredSets(address operator) external view returns (OperatorSet[] memory);
Fields
operator: AddressTrait Implementations
Sourceimpl Clone for getRegisteredSetsCall
impl Clone for getRegisteredSetsCall
Sourcefn clone(&self) -> getRegisteredSetsCall
fn clone(&self) -> getRegisteredSetsCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getRegisteredSetsCall
impl Debug for getRegisteredSetsCall
Sourceimpl Default for getRegisteredSetsCall
impl Default for getRegisteredSetsCall
Sourcefn default() -> getRegisteredSetsCall
fn default() -> getRegisteredSetsCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getRegisteredSetsCall
impl<'de> Deserialize<'de> for getRegisteredSetsCall
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for getRegisteredSetsCall
impl Hash for getRegisteredSetsCall
Sourceimpl PartialEq for getRegisteredSetsCall
impl PartialEq for getRegisteredSetsCall
Sourcefn eq(&self, other: &getRegisteredSetsCall) -> bool
fn eq(&self, other: &getRegisteredSetsCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for getRegisteredSetsCall
impl Serialize for getRegisteredSetsCall
Sourceimpl SolCall for getRegisteredSetsCall
impl SolCall for getRegisteredSetsCall
Sourcetype Parameters<'a> = (Address,)
type Parameters<'a> = (Address,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<getRegisteredSetsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getRegisteredSetsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Array<OperatorSet>,)
type ReturnTuple<'a> = (Array<OperatorSet>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<getRegisteredSetsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getRegisteredSetsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for getRegisteredSetsCall
impl StructuralPartialEq for getRegisteredSetsCall