pub struct getStrategyAllocationsCall {
pub operator: Address,
pub strategy: Address,
}Expand description
Function with signature getStrategyAllocations(address,address) and selector 0x40120dab.
solidity function getStrategyAllocations(address operator, address strategy) external view returns (OperatorSet[] memory, IAllocationManagerTypes.Allocation[] memory);
Fields
operator: Addressstrategy: AddressTrait Implementations
Sourceimpl Clone for getStrategyAllocationsCall
impl Clone for getStrategyAllocationsCall
Sourcefn clone(&self) -> getStrategyAllocationsCall
fn clone(&self) -> getStrategyAllocationsCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getStrategyAllocationsCall
impl Debug for getStrategyAllocationsCall
Sourceimpl Default for getStrategyAllocationsCall
impl Default for getStrategyAllocationsCall
Sourcefn default() -> getStrategyAllocationsCall
fn default() -> getStrategyAllocationsCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getStrategyAllocationsCall
impl<'de> Deserialize<'de> for getStrategyAllocationsCall
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for getStrategyAllocationsCall
impl Hash for getStrategyAllocationsCall
Sourceimpl PartialEq for getStrategyAllocationsCall
impl PartialEq for getStrategyAllocationsCall
Sourcefn eq(&self, other: &getStrategyAllocationsCall) -> bool
fn eq(&self, other: &getStrategyAllocationsCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl SolCall for getStrategyAllocationsCall
impl SolCall for getStrategyAllocationsCall
Sourceconst SIGNATURE: &'static str = "getStrategyAllocations(address,address)"
const SIGNATURE: &'static str = "getStrategyAllocations(address,address)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Address, Address)
type Parameters<'a> = (Address, Address)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<getStrategyAllocationsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getStrategyAllocationsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = getStrategyAllocationsReturn
type Return = getStrategyAllocationsReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = (Array<OperatorSet>, Array<Allocation>)
type ReturnTuple<'a> = (Array<OperatorSet>, Array<Allocation>)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<getStrategyAllocationsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getStrategyAllocationsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for getStrategyAllocationsCall
impl StructuralPartialEq for getStrategyAllocationsCall