pub struct deregisterOperatorFromAVSCall {
pub operator: Address,
}Expand description
Function with signature deregisterOperatorFromAVS(address) and selector 0xa364f4da.
solidity function deregisterOperatorFromAVS(address operator) external;
Fields
operator: AddressTrait Implementations
Sourceimpl Clone for deregisterOperatorFromAVSCall
impl Clone for deregisterOperatorFromAVSCall
Sourcefn clone(&self) -> deregisterOperatorFromAVSCall
fn clone(&self) -> deregisterOperatorFromAVSCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for deregisterOperatorFromAVSCall
impl Default for deregisterOperatorFromAVSCall
Sourcefn default() -> deregisterOperatorFromAVSCall
fn default() -> deregisterOperatorFromAVSCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for deregisterOperatorFromAVSCall
impl<'de> Deserialize<'de> for deregisterOperatorFromAVSCall
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for deregisterOperatorFromAVSCall
impl Hash for deregisterOperatorFromAVSCall
Sourceimpl PartialEq for deregisterOperatorFromAVSCall
impl PartialEq for deregisterOperatorFromAVSCall
Sourcefn eq(&self, other: &deregisterOperatorFromAVSCall) -> bool
fn eq(&self, other: &deregisterOperatorFromAVSCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl SolCall for deregisterOperatorFromAVSCall
impl SolCall for deregisterOperatorFromAVSCall
Sourceconst SIGNATURE: &'static str = "deregisterOperatorFromAVS(address)"
const SIGNATURE: &'static str = "deregisterOperatorFromAVS(address)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Address,)
type Parameters<'a> = (Address,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<deregisterOperatorFromAVSCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<deregisterOperatorFromAVSCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = deregisterOperatorFromAVSReturn
type Return = deregisterOperatorFromAVSReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<deregisterOperatorFromAVSCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<deregisterOperatorFromAVSCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for deregisterOperatorFromAVSCall
impl StructuralPartialEq for deregisterOperatorFromAVSCall