pub struct deregisterOperatorFromOperatorSetsCall {
pub operator: Address,
pub operatorSetIds: Vec<u32>,
}Expand description
Function with signature deregisterOperatorFromOperatorSets(address,uint32[]) and selector 0xc1a8e2c5.
solidity function deregisterOperatorFromOperatorSets(address operator, uint32[] memory operatorSetIds) external;
Fields
operator: AddressoperatorSetIds: Vec<u32>Trait Implementations
Sourceimpl Clone for deregisterOperatorFromOperatorSetsCall
impl Clone for deregisterOperatorFromOperatorSetsCall
Sourcefn clone(&self) -> deregisterOperatorFromOperatorSetsCall
fn clone(&self) -> deregisterOperatorFromOperatorSetsCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for deregisterOperatorFromOperatorSetsCall
impl Default for deregisterOperatorFromOperatorSetsCall
Sourcefn default() -> deregisterOperatorFromOperatorSetsCall
fn default() -> deregisterOperatorFromOperatorSetsCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for deregisterOperatorFromOperatorSetsCall
impl<'de> Deserialize<'de> for deregisterOperatorFromOperatorSetsCall
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for deregisterOperatorFromOperatorSetsCall
impl PartialEq for deregisterOperatorFromOperatorSetsCall
Sourcefn eq(&self, other: &deregisterOperatorFromOperatorSetsCall) -> bool
fn eq(&self, other: &deregisterOperatorFromOperatorSetsCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl SolCall for deregisterOperatorFromOperatorSetsCall
impl SolCall for deregisterOperatorFromOperatorSetsCall
Sourceconst SIGNATURE: &'static str = "deregisterOperatorFromOperatorSets(address,uint32[])"
const SIGNATURE: &'static str = "deregisterOperatorFromOperatorSets(address,uint32[])"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Address, Array<Uint<32>>)
type Parameters<'a> = (Address, Array<Uint<32>>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<deregisterOperatorFromOperatorSetsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<deregisterOperatorFromOperatorSetsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = deregisterOperatorFromOperatorSetsReturn
type Return = deregisterOperatorFromOperatorSetsReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<deregisterOperatorFromOperatorSetsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<deregisterOperatorFromOperatorSetsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for deregisterOperatorFromOperatorSetsCall
impl StructuralPartialEq for deregisterOperatorFromOperatorSetsCall